var assert = require('assert');
var util = require('../lib/util');

describe('ack util', function () {

  describe('isDomainWhitelisted', function () {

    it('should return false with no arguments', function () {
      assert.ok(!util.isDomainWhitelisted());
    });

    it('should return false with a value tested against an empty whitelist', function () {
      assert.ok(!util.isDomainWhitelisted([], 'http://foo.com'));
    });

    it('should return true with a literal match', function () {
      assert.ok(util.isDomainWhitelisted(['foo.com', 'bar.com'], 'http://bar.com'));
    });

    it('should return true with a glob match among many arguments', function () {
      assert.ok(util.isDomainWhitelisted(['*.foo.com', '*.bar.com'], 'http://baz.bar.com'));
    });

  });

  describe('isGeneratorFunction', function () {

    it('should return false with no arguments', function () {
      assert.ok(!util.isGeneratorFunction());
    });

    it('should return false with a non-function argument', function () {
      assert.ok(!util.isGeneratorFunction({}));
    });

    it('should return false with a non-generator function argument', function () {
      assert.ok(!util.isGeneratorFunction(function () {}));
    });

    it('should return true with a generator function argument', function () {
      assert.ok(util.isGeneratorFunction(function *() {}));
    });

  });

});
